import { ComputedStyleStorage } from './ComputedStyleStorage.js';
import { RevealBoundaryStore } from './RevealBoundryStore.js';
declare type BorderDecoration = 'round' | 'bevel' | 'miter';
export interface CachedStyle {
    top: number;
    left: number;
    width: number;
    height: number;
    color: string;
    opacity: number;
    trueFillRadius: number[];
    borderStyle: string;
    borderDecorationType: BorderDecoration;
    borderDecorationSize: number;
    borderWidth: number;
    fillMode: string;
    fillRadius: number;
    diffuse: boolean;
    revealAnimateSpeed: number;
    revealReleasedAccelerateRate: number;
}
/**
 * Cached mask of current reveal effect,
 * will update each time if the size of main canvas changed.
 * @interface CachedMask
 * @property {number} width The width of cached mask
 * @property {number} height The height of cached mask
 * @property {BorderDecoration}  borderDecorationType The shape of the border decoration
 * @property {number}  borderDecorationSize The size of the border decoration
 * @property {HTMLCanvasElement} borderMask Canvas with cached mask of border, to draw rounded and tangential corners
 * @property {HTMLCanvasElement} fillMask Canvas with cached mask of the filling
 */
interface CachedMask {
    width: number;
    height: number;
    borderDecorationType: BorderDecoration;
    borderDecorationSize: number;
}
/**
 * Cached gradient of current reveal effect,
 * will update each time if the color, radius parameter changed.
 * @interface CachedMask
 * @property {number} radius - The radius of the radial gradient
 * @property {string} color - The color of the gradient
 * @property {number} opacity - The central opacity of the radial gradient
 * @property {HTMLCanvasElement} borderReveal Canvas with cached gradient of border
 * @property {HTMLCanvasElement} fillReveal Canvas with cached gradient of reveal
 */
interface CachedReveal {
    radius: number;
    color: string;
    opacity: number;
}
/**
 * Cached border and body pattern, for faster painting on the canvas.
 * @interface CachedRevealBitmap

 * @property {CachedMask} cachedMask cached mask canvases
 * @property {HTMLCanvasElement} cachedCanvas.borderMask Canvas with cached mask of border, to draw rounded and tangential corners
 * @property {HTMLCanvasElement} cachedCanvas.fillMask Canvas with cached mask of the filling
 */
export interface CachedRevealBitmap {
    cachedMask: CachedMask | null;
    cachedReveal: CachedReveal | null;
    cachedCanvas: {
        borderReveal: HTMLCanvasElement;
        fillReveal: HTMLCanvasElement;
        borderMask: HTMLCanvasElement;
        fillMask: HTMLCanvasElement;
    };
    cachedCtx: {
        borderReveal: CanvasRenderingContext2D | null;
        fillReveal: CanvasRenderingContext2D | null;
        borderMask: CanvasRenderingContext2D | null;
        fillMask: CanvasRenderingContext2D | null;
    };
}
export declare class CanvasConfig {
    protected _store: RevealBoundaryStore;
    pxRatio: number;
    canvas: HTMLCanvasElement;
    ctx: CanvasRenderingContext2D | null;
    computedStyle: ComputedStyleStorage;
    paintedWidth: number;
    paintedHeight: number;
    bufferCanvas: HTMLCanvasElement;
    bufferCtx: CanvasRenderingContext2D | null;
    cachedImg: CachedRevealBitmap;
    cachedStyle: CachedStyle;
    mouseUpClientX: number | null;
    mouseUpClientY: number | null;
    mouseDownAnimateStartFrame: number | null;
    mouseDownAnimateCurrentFrame: number | null;
    mouseDownAnimateReleasedFrame: number | null;
    mouseDownAnimateLogicFrame: number | null;
    mousePressed: boolean;
    mouseReleased: boolean;
    currentFrameId: any;
    cachedFrameId: any;
    constructor(store: RevealBoundaryStore, $el: HTMLCanvasElement);
    cacheCanvasPaintingStyle: () => void;
    updateCachedMask: () => {
        width: number;
        height: number;
        borderDecorationSize: number;
        borderDecorationType: BorderDecoration;
    } | undefined;
    updateCachedReveal: () => {
        radius: number;
        color: string;
        opacity: number;
        borderReveal: HTMLCanvasElement;
        fillReveal: HTMLCanvasElement;
    } | undefined;
    updateCachedBitmap: () => void;
    mouseInCanvas: () => boolean;
    syncSizeToElement: (x: HTMLCanvasElement) => void;
    syncSizeToRevealRadius: (x: HTMLCanvasElement) => void;
    getAnimateGrd: (frame: number, grd: CanvasGradient) => void;
    paint: (force?: boolean | undefined, debug?: boolean | undefined) => void;
}
export {};
//# sourceMappingURL=CanvasConfig.d.ts.map